==> cybop-0.18.0.tar.gz: cybop-0.18.0/src/constant/name/cybol/logic/memory/create_memory_logic_cybol_name.c <==
/*
 * Copyright (C) 1999-2016. Christian Heller.
 *
 * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
 *
 * CYBOI is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * CYBOI is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with CYBOI. If not, see <http://www.gnu.org/licenses/>.
 *
 * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
 * CYBOP Developers <cybop-developers@nongnu.org>
 *
 * @version CYBOP 0.18.0 2016-12-21
 * @author Christian Heller <christian.heller@tuxtax.de>
 */

#ifndef CREATE_MEMORY_LOGIC_CYBOL_NAME_CONSTANT_SOURCE
#define CREATE_MEMORY_LOGIC_CYBOL_NAME_CONSTANT_SOURCE

#include <stddef.h>

#include "../../../../../constant/model/cyboi/state/integer_state_cyboi_model.c"

/** The name create memory logic cybol name. */
static wchar_t NAME_CREATE_MEMORY_LOGIC_CYBOL_NAME_ARRAY[] = {L'n', L'a', L'm', L'e'};
static wchar_t* NAME_CREATE_MEMORY_LOGIC_CYBOL_NAME = NAME_CREATE_MEMORY_LOGIC_CYBOL_NAME_ARRAY;
static int* NAME_CREATE_MEMORY_LOGIC_CYBOL_NAME_COUNT = NUMBER_4_INTEGER_STATE_CYBOI_MODEL_ARRAY;

/** The format create memory logic cybol name. */
static wchar_t FORMAT_CREATE_MEMORY_LOGIC_CYBOL_NAME_ARRAY[] = {L'f', L'o', L'r', L'm', L'a', L't'};
static wchar_t* FORMAT_CREATE_MEMORY_LOGIC_CYBOL_NAME = FORMAT_CREATE_MEMORY_LOGIC_CYBOL_NAME_ARRAY;
static int* FORMAT_CREATE_MEMORY_LOGIC_CYBOL_NAME_COUNT = NUMBER_6_INTEGER_STATE_CYBOI_MODEL_ARRAY;

/** The element create memory logic cybol name. */
static wchar_t ELEMENT_CREATE_MEMORY_LOGIC_CYBOL_NAME_ARRAY[] = {L'e', L'l', L'e', L'm', L'e', L'n', L't'};
static wchar_t* ELEMENT_CREATE_MEMORY_LOGIC_CYBOL_NAME = ELEMENT_CREATE_MEMORY_LOGIC_CYBOL_NAME_ARRAY;
static int* ELEMENT_CREATE_MEMORY_LOGIC_CYBOL_NAME_COUNT = NUMBER_7_INTEGER_STATE_CYBOI_MODEL_ARRAY;

/** The whole create memory logic cybol name. */
static wchar_t WHOLE_CREATE_MEMORY_LOGIC_CYBOL_NAME_ARRAY[] = {L'w', L'h', L'o', L'l', L'e'};
static wchar_t* WHOLE_CREATE_MEMORY_LOGIC_CYBOL_NAME = WHOLE_CREATE_MEMORY_LOGIC_CYBOL_NAME_ARRAY;
static int* WHOLE_CREATE_MEMORY_LOGIC_CYBOL_NAME_COUNT = NUMBER_5_INTEGER_STATE_CYBOI_MODEL_ARRAY;

/* CREATE_MEMORY_LOGIC_CYBOL_NAME_CONSTANT_SOURCE */
#endif

==> cybop-0.19.0.tar.gz: cybop-0.19.0/src/constant/name/cybol/logic/memory/create_memory_logic_cybol_name.c <==
/*
 * Copyright (C) 1999-2017. Christian Heller.
 *
 * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
 *
 * CYBOI is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * CYBOI is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with CYBOI. If not, see <http://www.gnu.org/licenses/>.
 *
 * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
 * CYBOP Developers <cybop-developers@nongnu.org>
 *
 * @version CYBOP 0.19.0 2017-04-10
 * @author Christian Heller <christian.heller@tuxtax.de>
 */

#ifndef CREATE_MEMORY_LOGIC_CYBOL_NAME_CONSTANT_SOURCE
#define CREATE_MEMORY_LOGIC_CYBOL_NAME_CONSTANT_SOURCE

#include <stddef.h>

#include "../../../../../constant/model/cyboi/state/integer_state_cyboi_model.c"

/** The name create memory logic cybol name. */
static wchar_t* NAME_CREATE_MEMORY_LOGIC_CYBOL_NAME = L"name";
static int* NAME_CREATE_MEMORY_LOGIC_CYBOL_NAME_COUNT = NUMBER_4_INTEGER_STATE_CYBOI_MODEL_ARRAY;

/** The format create memory logic cybol name. */
static wchar_t* FORMAT_CREATE_MEMORY_LOGIC_CYBOL_NAME = L"format";
static int* FORMAT_CREATE_MEMORY_LOGIC_CYBOL_NAME_COUNT = NUMBER_6_INTEGER_STATE_CYBOI_MODEL_ARRAY;

/** The element create memory logic cybol name. */
static wchar_t* ELEMENT_CREATE_MEMORY_LOGIC_CYBOL_NAME = L"element";
static int* ELEMENT_CREATE_MEMORY_LOGIC_CYBOL_NAME_COUNT = NUMBER_7_INTEGER_STATE_CYBOI_MODEL_ARRAY;

/** The whole create memory logic cybol name. */
static wchar_t* WHOLE_CREATE_MEMORY_LOGIC_CYBOL_NAME = L"whole";
static int* WHOLE_CREATE_MEMORY_LOGIC_CYBOL_NAME_COUNT = NUMBER_5_INTEGER_STATE_CYBOI_MODEL_ARRAY;

/* CREATE_MEMORY_LOGIC_CYBOL_NAME_CONSTANT_SOURCE */
#endif
